slepc-3.18.0 2022-10-01
Report Typos and Errors

# STScaleShift

Multiply the shift with a given factor.

### Synopsis

    #include "slepcst.h"
    PetscErrorCode STScaleShift(ST st,PetscScalar factor)

Logically Collective on st

### Input Parameters

| st | - the spectral transformation context
| factor | - the scaling factor

### Note

This function does not update the transformation matrices, as opposed to STSetShift().

### See Also

STSetShift()

### Level

developer

### Location

src/sys/classes/st/interface/stfunc.c
Index of all ST routines
Table of Contents for all manual pages
Index of all manual pages